@@ -314,7 +314,7 @@ proc CATDialog {varname format catalog title action} {
 
     CoordMenuButton $f.coord $varname system 0 sky skyformat \
 	[list CATWCSMenuUpdate $varname]
-    CoordMenuEnable $f.coord.menu $varname system {} sky skyformat
+    CoordMenuEnable $f.coord.menu $varname system sky skyformat
 
     ttk::button $f.update -text [msgcat::mc {Update}] \
 	-command [list CATUpdate $varname]
@@ -377,7 +377,7 @@ proc CATDialog {varname format catalog title action} {
 
     CoordMenuButton $f.pcoord $varname psystem 1 psky {} \
 	[list CATColsCmd $varname]
-    CoordMenuEnable $f.pcoord.menu $varname psystem 1 psky {}
+    CoordMenuEnable $f.pcoord.menu $varname psystem psky {}
 
     grid $f.mfilter $f.filter - - $f.bfilter \
 	-padx 2 -pady 2 -sticky w
@@ -391,6 +391,12 @@ proc CATDialog {varname format catalog title action} {
     # Table
     set f [ttk::frame $w.tbl]
 
+    # set the col width
+    switch $var(format) {
+	cxc {set cw 18}
+	default {set cw 14}
+    }
+
     set var(tbl) [table $f.t \
 		      -state disabled \
 		      -usecommand 0 \
@@ -401,6 +407,7 @@ proc CATDialog {varname format catalog title action} {
 		      -rows $icat(minrows) \
 		      -width -1 \
 		      -height -1 \
+		      -colwidth $cw \
 		      -maxwidth 300 \
 		      -maxheight 300 \
 		      -titlerows 1 \
@@ -411,6 +418,7 @@ proc CATDialog {varname format catalog title action} {
 		      -anchor w \
 		      -font [font actual TkDefaultFont] \
 		      -browsecommand [list CATSelectCmd $varname %s %S] \
+		      -fg $ds9(gui,fg) -bg $ds9(gui,bg) \
 		     ]
 
     ttk::scrollbar $f.yscroll -command [list $var(tbl) yview] -orient vertical
@@ -525,7 +533,7 @@ proc CATDialogUpdate {varname} {
 	$var(mb).file entryconfig [msgcat::mc {Plot}] -state disabled
 	$var(mb).file entryconfig "[msgcat::mc {Display Header}]..." \
 	    -state disabled
-	$var(mb).file entryconfig [msgcat::mc {Copy to Regions}] -stat disabled
+	$var(mb).file entryconfig [msgcat::mc {Copy to Regions}] -state disabled
 	$var(mb).file entryconfig "[msgcat::mc {Print}]..." -state disabled
 
 	$var(top).buttons.filter configure -state disabled
@@ -576,7 +584,6 @@ proc CATAck {varname} {
 	cxc {CATCXCAck $varname}
 	ned {CATNEDAck $varname}
 	skybot {CATSkyBotAck $varname}
-	sdss {CATSDSSAck $varname}
 	simbad {CATSIMBADAck $varname}
     }
 }
@@ -907,7 +914,6 @@ proc CATPrint {varname} {
 	x11 -
 	aqua -
 	win32 {CATPSPrint $varname}
-	wwin32 {win32 pm print text [::textutil::tabify::untabify2 [starbase_write_ $var(tbldb)] 12]}
     }	
 }
 
@@ -956,7 +962,6 @@ proc CATServer {varname} {
 	    cxc {CATCXC $varname}
 	    ned {CATNED $varname}
 	    skybot {CATSkyBot $varname}
-	    sdss {CATSDSS $varname}
 	    simbad {CATSIMBAD $varname}
 	}
     } else {
