@@ -70,7 +70,8 @@ proc CreateColorbar {} {
 	-anchor nw \
 	-helvetica $ds9(helvetica) \
 	-courier $ds9(courier) \
-	-times $ds9(times)
+	-times $ds9(times) \
+	-fg $ds9(foreground) -bg $ds9(background)
 
     $ds9(canvas) bind colorbar <Motion> [list ColorbarMotion %x %y]
     $ds9(canvas) bind colorbar <Enter> [list ColorbarEnter %x %y]
@@ -93,7 +94,8 @@ proc CreateColorbar {} {
 	-anchor nw \
 	-helvetica $ds9(helvetica) \
 	-courier $ds9(courier) \
-	-times $ds9(times)
+	-times $ds9(times) \
+	-fg $ds9(foreground) -bg $ds9(background)
 
     $ds9(canvas) bind colorbarrgb <Motion> [list ColorbarMotion %x %y]
     $ds9(canvas) bind colorbarrgb <Enter> [list ColorbarEnter %x %y]
@@ -133,33 +135,39 @@ proc LoadColormap {} {
 }
 
 # used by backup
-proc LoadColormapFile {filename} {
+proc LoadColormapFile {fn} {
     global colorbar
     global icolorbar
 
     global current
     global ds9
 
-    if {$filename != {}} {
-	colorbar load "\{$filename\}"
-	set id [colorbar get id]
-	set colorbar(map) [colorbar get name]
+    if {$fn == {}} {
+	return
+    }
 
-	$ds9(mb).color.user add radiobutton \
+    if {[catch {colorbar load "\{$fn\}"} rr]} {
+	Error $rr
+	return
+    }
+    
+    set id [colorbar get id]
+    set colorbar(map) [colorbar get name]
+
+    $ds9(mb).color.user add radiobutton \
+	-label "$colorbar(map)" \
+	-variable colorbar(map) \
+	-command [list ChangeColormapID $id]
+
+    if {[winfo exists $icolorbar(top)]} {
+	$icolorbar(mb).colormap.user add radiobutton \
 	    -label "$colorbar(map)" \
 	    -variable colorbar(map) \
 	    -command [list ChangeColormapID $id]
-
-	if {[winfo exists $icolorbar(top)]} {
-	    $icolorbar(mb).colormap.user add radiobutton \
-		-label "$colorbar(map)" \
-		-variable colorbar(map) \
-		-command [list ChangeColormapID $id]
-	}
-	incr icolorbar(count)
-
-	ChangeColormapID $id
     }
+    incr icolorbar(count)
+
+    ChangeColormapID $id
 }
 
 proc SaveColormap {} {
@@ -167,36 +175,45 @@ proc SaveColormap {} {
     SaveColormapFile [SaveFileDialog colorbarfbox]
 }
 
-proc SaveColormapFile {filename} {
-    if {$filename != {}} {
-	colorbar save "\{$filename\}"
+proc SaveColormapFile {fn} {
+    if {$fn == {}} {
+	return
+    }
+
+    if {[catch {colorbar save "\{$fn\}"} rr]} {
+	Error $rr
+	return
     }
 }
 
 proc LoadContrastBias {} {
     global dcolorbar
 
-    set filename [OpenFileDialog contrastbiasfbox]
-    if {$filename != {}} {
-	if {![catch {set ch [open $filename r]}]} {
-	    set ll [gets $ch]
-	    close $ch
-	    set dcolorbar(contrast) [lindex $ll 0]
-	    set dcolorbar(bias) [lindex $ll 1]
-	    ApplyColormap
-	}
+    set fn [OpenFileDialog contrastbiasfbox]
+    if {$fn == {}} {
+	return
+    }
+
+    if {![catch {set ch [open $fn r]}]} {
+	set ll [gets $ch]
+	close $ch
+	set dcolorbar(contrast) [lindex $ll 0]
+	set dcolorbar(bias) [lindex $ll 1]
+	ApplyColormap
     }
 }
 
 proc SaveContrastBias {} {
     global dcolorbar
 
-    set filename [SaveFileDialog contrastbiasfbox]
-    if {$filename != {}} {
-	if {![catch {set ch [open $filename w]}]} {
-	    puts $ch "$dcolorbar(contrast) $dcolorbar(bias)"
-	    close $ch
-	}
+    set fn [SaveFileDialog contrastbiasfbox]
+    if {$fn == {}} {
+	return
+    }
+    
+    if {![catch {set ch [open $fn w]}]} {
+	puts $ch "$dcolorbar(contrast) $dcolorbar(bias)"
+	close $ch
     }
 }
 
@@ -218,8 +235,8 @@ proc ColorbarEnter {x y} {
     $ds9(canvas) focus $current(colorbar)
 
     switch -- $current(colorbar) {
-	colorbar {LayoutFrameInfoBox base}
-	colorbarrgb {LayoutFrameInfoBox rgb}
+	colorbar {LayoutFrameInfoBox $current(frame) base}
+	colorbarrgb {LayoutFrameInfoBox $current(frame) rgb}
     }
 }
 
@@ -288,6 +305,7 @@ proc ColorbarKey {K A xx yy} {
 		    $current(colorbar) tag delete $xx $yy
 		    if {$current(frame) != {}} {
 			$current(frame) colormap [$current(colorbar) get colormap]
+			$current(frame) colorbar tag "\{[$current(colorbar) get tag]\}"
 		    }
 		}
 	    }
@@ -358,6 +376,7 @@ proc ColorbarMotion1 {x y} {
 	    $current(colorbar) tag edit motion $x $y
 	    if {$current(frame) != {}} {
 		$current(frame) colormap [$current(colorbar) get colormap]
+		$current(frame) colorbar tag "\{[$current(colorbar) get tag]\}"
 	    }
 	}
     }
@@ -390,6 +409,7 @@ proc ColorbarRelease1 {x y} {
 	    $current(colorbar) tag edit end $x $y
 	    if {$current(frame) != {}} {
 		$current(frame) colormap [$current(colorbar) get colormap]
+		$current(frame) colorbar tag "\{[$current(colorbar) get tag]\}"
 	    }
 	}
     }
@@ -671,9 +691,15 @@ proc LoadColorTag {fn} {
     global current
 
     if {$fn != {}} {
-	$current(colorbar) tag load "\{$fn\}"
+	# yes, we need this
+	UpdateColormapLevel
+	if {[catch {$current(colorbar) tag load "\{$fn\}"} rr]} {
+	    Error $rr
+	    return
+	}
 	if {$current(frame) != {}} {
 	    $current(frame) colormap [$current(colorbar) get colormap]
+	    $current(frame) colorbar tag "\{[$current(colorbar) get tag]\}"
 	}
     }
 }
@@ -682,8 +708,13 @@ proc SaveColorTag {} {
     global current
 
     set fn [SaveFileDialog colortagfbox]
-    if {$fn != {}} {
-	$current(colorbar) tag save "\{$fn\}"
+    if {$fn == {}} {
+	return
+    }
+
+    if {[catch {colorbar tag save "\{$fn\}"} rr]} {
+	Error $rr
+	return
     }
 }
 
@@ -693,6 +724,7 @@ proc DeleteColorTag {} {
     $current(colorbar) tag delete
     if {$current(frame) != {}} {
 	$current(frame) colormap [$current(colorbar) get colormap]
+	$current(frame) colorbar tag "\{[$current(colorbar) get tag]\}"
     }
 }
 
@@ -750,6 +782,7 @@ proc ColorTagDialog {x y} {
 	$current(colorbar) tag $ed2(id) $ed2(start) $ed2(stop) $ed2(color)
 	if {$current(frame) != {}} {
 	    $current(frame) colormap [$current(colorbar) get colormap]
+	    $current(frame) colorbar tag "\{[$current(colorbar) get tag]\}"
 	}
     }
 
@@ -1072,7 +1105,7 @@ proc LayoutColorbar {} {
 	-font $colorbar(font) \
 	-fontsize $colorbar(font,size) \
 	-fontweight $colorbar(font,weight) \
-	-fontslant $colorbar(font,slant) \
+	-fontslant $colorbar(font,slant)
 
     colorbarrgb configure \
 	-size $colorbar(size) \
@@ -1082,7 +1115,7 @@ proc LayoutColorbar {} {
 	-font $colorbar(font) \
 	-fontsize $colorbar(font,size) \
 	-fontweight $colorbar(font,weight) \
-	-fontslant $colorbar(font,slant) \
+	-fontslant $colorbar(font,slant)
 
     switch -- $colorbar(orientation) {
 	horizontal {
