@@ -14,7 +14,6 @@ proc BadVisualError {} {
 proc ProcessCommandLineFirst {} {
     global argc
     global argv
-    global icolorbar
     global ds9
     global pds9
 
@@ -23,10 +22,26 @@ proc ProcessCommandLineFirst {} {
 	set item [lindex $argv $i]
 
 	switch -- $item {
-	    -help {
-		puts "For more information, use --help"
-		QuitDS9
+	    -prefs {
+		incr i
+		ProcessPrefsFirstCmd argv i
 	    }
+	}
+	incr i
+    }
+}
+
+proc ProcessCommandLineSecond {} {
+    global argc
+    global argv
+    global ds9
+    global pds9
+
+    set i 0
+    while {$i < $argc} {
+	set item [lindex $argv $i]
+
+	switch -- $item {
 	    -debug {
 		incr i
 		ProcessDebugTclCmd argv i
@@ -555,7 +570,7 @@ proc CommandLineLoadBase {item argvname iname} {
 	    MultiLoad $file(layer)
 	    switch -- $file(mosaic) {
 		iraf {LoadMosaicImageIRAFFile $item $file(layer)}
-		wfpc2 {LoadMosaicImageWFPC2File $item}
+		wfpc2 {LoadMosaicImageWFPC2File $item $file(layer)}
 		default {LoadMosaicImageWCSFile $item $file(layer) $file(mosaic)}
 	    }
 	}
@@ -647,7 +662,7 @@ proc CommandLineLoadRGB {item argvname iname} {
 	mosaicimage {
 	    switch -- $file(mosaic) {
 		iraf {LoadMosaicImageIRAFFile $item {}}
-		wfpc2 {LoadMosaicImageWFPC2File $item}
+		wfpc2 {LoadMosaicImageWFPC2File $item {}}
 		default {LoadMosaicImageWCSFile $item {} $file(mosaic)}
 	    }
 	}
@@ -734,7 +749,7 @@ proc CommandLineLoad3D {item argvname iname} {
 	    MultiLoad
 	    switch -- $file(mosaic) {
 		iraf {LoadMosaicImageIRAFFile $item {}}
-		wfpc2 {LoadMosaicImageWFPC2File $item}
+		wfpc2 {LoadMosaicImageWFPC2File $item {}}
 		default {LoadMosaicImageWCSFile $item {} $file(mosaic)}
 	    }
 	}
