@@ -113,7 +113,8 @@ proc CreateNameNumberFrame {which type} {
 	-tag $ds9(next) \
 	-helvetica $ds9(helvetica) \
 	-courier $ds9(courier) \
-	-times $ds9(times)
+	-times $ds9(times) \
+	-fg $ds9(foreground) -bg $ds9(background)
 
     $ds9(next) threads $ds9(threads)
 
@@ -240,9 +241,7 @@ proc CreateNameNumberFrame {which type} {
     }
 
     switch $current(mode) {
-	crosshair {
-	    $ds9(next) crosshair on
-	}
+	crosshair {$ds9(next) crosshair on}
     }
 
     UpdateFrameMenuItems
@@ -566,14 +565,14 @@ proc EnterFrame {which x y} {
     $ds9(canvas) focus $which
 
     switch -- $current(mode) {
+	none -
+	pointer -
+	region {}
 	crosshair {
 	    set coord [$which get crosshair canvas]
 	    set x [lindex $coord 0]
 	    set y [lindex $coord 1]
 	}
-	none -
-	pointer -
-	region -
 	catalog -
 	pan -
 	zoom -
@@ -581,7 +580,8 @@ proc EnterFrame {which x y} {
 	crop -
 	colorbar -
 	examine -
-	iexam {}
+	iexam -
+	3d {}
     }
 
     EnterInfoBox $which
@@ -621,8 +621,6 @@ proc LeaveFrame {which} {
     $ds9(canvas) focus {}
 
     switch -- $current(mode) {
-	crosshair {}
-
 	none -
 	pointer -
 	region -
@@ -633,11 +631,13 @@ proc LeaveFrame {which} {
 	crop -
 	catalog -
 	examine -
-	iexam {
+	iexam -
+	3d {
 	    LeaveInfoBox
 	    PixelTableClearDialog
 	    ClearGraphData
 	}
+	crosshair {}
     }
 
     $which magnifier off
@@ -700,7 +700,8 @@ proc DoMotion {which x y cursor1 cursor2} {
 	rotate -
 	crop -
 	examine -
-	iexam {
+	iexam -
+	3d {
 	    UpdateColormapLevelMosaic $which $x $y canvas
 	    UpdateInfoBox $which $x $y canvas
 	    UpdatePixelTableDialog $which $x $y canvas
@@ -765,9 +766,7 @@ proc Button1Frame {which x y} {
 	    UpdateGraphData $which $x $y canvas
 	    UpdateMagnifier $which $x $y
 	}
-	colorbar {
-	    ColorbarButton3 $x $y
-	}
+	colorbar {ColorbarButton3 $x $y}
 	pan {
 	    PanButton $which $x $y
 	    UpdateMagnifier $which $x $y
@@ -797,6 +796,7 @@ proc Button1Frame {which x y} {
 	}
 	examine {ExamineButton $which $x $y}
 	iexam {IExamButton $which $x $y}
+	3d {}
     }
 }
 
@@ -836,8 +836,9 @@ proc ShiftButton1Frame {which x y} {
 	    }
 	    UpdateMagnifier $which $x $y
 	}
-	examine -
+	examine {}
 	iexam {}
+	3d {}
     }
 }
 
@@ -879,8 +880,9 @@ proc ControlButton1Frame {which x y} {
 	    Crop3dButton $which $x $y 1
 	    UpdateMagnifier $which $x $y
 	}
-	examine -
+	examine {}
 	iexam {}
+	3d {}
     }
 }
 
@@ -920,7 +922,8 @@ proc ControlShiftButton1Frame {which x y} {
 	rotate -
 	crop -
 	examine -
-	iexam {}
+	iexam -
+	3d {}
     }
 }
 
@@ -1003,8 +1006,13 @@ proc Motion1Frame {which x y} {
 	    UpdateGraphData $which $x $y canvas
 	    UpdateMagnifier $which $x $y
 	}
-	examine -
+	examine {}
 	iexam {}
+	3d {
+	    if {$ds9(b1)} {
+		3DMotion $which $x $y
+	    }
+	}
     }
 }
 
@@ -1024,6 +1032,7 @@ proc Release1Frame {which x y} {
     }
 
     switch -- $current(mode) {
+	none {}
 	pointer -
 	region {
 	    if {$which == $current(frame)} {
@@ -1072,9 +1081,9 @@ proc Release1Frame {which x y} {
 		CATRelease $which $x $y
 	    }
 	}
-	none -
-	examine -
+	examine {}
 	iexam {}
+	3d {}
     }
 
     # let others know that the mouse is up
@@ -1113,6 +1122,8 @@ proc Double1Frame {which x y} {
 	catalog -
 	examine -
 	iexam {}
+	3d {3DDouble $which}
+	    
     }
 }
 
@@ -1136,7 +1147,8 @@ proc DoubleRelease1Frame {which x y} {
 	crop -
 	catalog -
 	examine -
-	iexam {}
+	iexam -
+	3d {}
     }
 
     UpdateEditMenu
@@ -1247,7 +1259,7 @@ proc MouseWheelFrame {X Y dd} {
 	puts stderr "MouseWheel $X $Y $dd"
     }
 
-    # macosx returns main window coords in X,Y
+    # macos returns main window coords in X,Y
     switch $ds9(wm) {
 	x11 -
 	win32 {}
@@ -1287,7 +1299,7 @@ proc KeyFrame {which K A xx yy} {
     global ds9
     global current
 
-    # MacOSX and Ubuntu returns bogus values in xx,yy
+    # MacOSX and maybe Ubuntu returns bogus values in xx,yy
     # calculate our own values
     set xx [expr {[winfo pointerx $ds9(canvas)] - [winfo rootx $ds9(canvas)]}]
     set yy [expr {[winfo pointery $ds9(canvas)] - [winfo rooty $ds9(canvas)]}]
@@ -1331,6 +1343,9 @@ proc KeyFrame {which K A xx yy} {
 		h {$which warp -1 0}
 		Right -
 		l {$which warp 1 0}
+
+		z {Zoom 2 2}
+		Z {Zoom .5 .5}
 	    }
 	}
 	pointer -
@@ -1363,6 +1378,9 @@ proc KeyFrame {which K A xx yy} {
 		b {$which marker property source 0 $xx $yy}
 		g {GroupCreate}
 		G {GroupCreateSilent}
+
+		z {Zoom 2 2}
+		Z {Zoom .5 .5}
 	    }    
 	}
 	crosshair {
@@ -1384,6 +1402,9 @@ proc KeyFrame {which K A xx yy} {
 		h {CrosshairArrowKey $which -1 0}
 		Right -
 		l {CrosshairArrowKey $which 1 0}
+
+		z {Zoom 2 2}
+		Z {Zoom .5 .5}
 	    }
 	}
 	pan {
@@ -1396,8 +1417,17 @@ proc KeyFrame {which K A xx yy} {
 		h {PanCanvas 1 0}
 		Right -
 		l {PanCanvas -1 0}
+
+		z {Zoom 2 2}
+		Z {Zoom .5 .5}
+	    }
+	}
+	zoom -
+	rotate {
+	    switch -- $K {
+		z {Zoom 2 2}
+		Z {Zoom .5 .5}
 	    }
-	    UpdateMagnifier $which $xx $yy
 	}
 	catalog {
 	    switch -- $K {
@@ -1414,12 +1444,28 @@ proc KeyFrame {which K A xx yy} {
 	}
 	iexam {IExamKey $which $K $xx $yy}
 	colorbar -
-	zoom -
-	rotate -
 	crop -
 	examine {}
+	3d {
+	    switch -- $K {
+		Up -
+		k {3DArrowKey $which 0 1}
+		Down -
+		j {3DArrowKey $which 0 -1}
+		Left -
+		h {3DArrowKey $which -1 0}
+		Right -
+		l {3DArrowKey $which 1 0}
+	    }
+
+	    z {Zoom 2 2}
+	    Z {Zoom .5 .5}
+	}
     }
 
+    # since most modes do zoom
+    UpdateMagnifier $which $xx $yy
+
     UpdateEditMenu
 }
 
@@ -1811,10 +1857,6 @@ proc ClearFrame {which} {
 	return
     }
 
-    DestroyHeader $which
-    $which clear
-
-    # delete saved loadParams
     foreach cc {{} red green blue} {
 	set varname $which$cc
 	global $varname
@@ -1822,6 +1864,31 @@ proc ClearFrame {which} {
 	    unset $varname
 	}
     }
+
+    set cnt [$which get fits count]
+    for {set ii 2} {$ii<=$cnt} {incr ii} {
+	set varname $which.$ii
+	global $varname
+	if {[info exists $varname]} {
+	    unset $varname
+	} else {
+	    break
+	}
+    }
+
+    set cnt [$which get mask count]
+    for {set ii 1} {$ii<=$cnt} {incr ii} {
+	set varname $which.m${ii}
+	global $varname
+	if {[info exists $varname]} {
+	    unset $varname
+	} else {
+	    break
+	}
+    }
+
+    DestroyHeader $which
+    $which clear
 }
 
 # Private Procedures
