@@ -99,9 +99,6 @@ proc CreateInfoPanel {} {
     ttk::label $ds9(info).detectorYLabel -text {y}
     ttk::label $ds9(info).detectorYValue -relief groove \
 	-textvariable infobox(detector,y) -anchor center
-    ttk::label $ds9(info).detectorZLabel -text {z}
-    ttk::label $ds9(info).detectorZValue -relief groove \
-	-textvariable infobox(detector,z) -anchor center
 
     ttk::label $ds9(info).amplifierTitle -text [msgcat::mc {Amplifier}]
     ttk::label $ds9(info).amplifierXLabel -text {x}
@@ -110,9 +107,6 @@ proc CreateInfoPanel {} {
     ttk::label $ds9(info).amplifierYLabel -text {y}
     ttk::label $ds9(info).amplifierYValue -relief groove \
 	-textvariable infobox(amplifier,y) -anchor center
-    ttk::label $ds9(info).amplifierZLabel -text {z}
-    ttk::label $ds9(info).amplifierZValue -relief groove \
-	-textvariable infobox(amplifier,z) -anchor center
 
     ttk::label $ds9(info).physicalTitle -text [msgcat::mc {Physical}]
     ttk::label $ds9(info).physicalXLabel -text {x}
@@ -121,9 +115,6 @@ proc CreateInfoPanel {} {
     ttk::label $ds9(info).physicalYLabel -text {y}
     ttk::label $ds9(info).physicalYValue -relief groove \
 	-textvariable infobox(physical,y) -anchor center
-    ttk::label $ds9(info).physicalZLabel -text {z}
-    ttk::label $ds9(info).physicalZValue -relief groove \
-	-textvariable infobox(physical,z) -anchor center
 
     ttk::label $ds9(info).imageTitle -text [msgcat::mc {Image}]
     ttk::label $ds9(info).imageXLabel -text {x}
@@ -148,231 +139,196 @@ proc CreateInfoPanel {} {
 	-textvariable infobox(angle) -anchor center
 }
 
-proc LayoutFrameInfoBox {which} {
-    global ds9
+proc LayoutFrameInfoBox {which type} {
     global view
 
     global debug
     if {$debug(tcl,events)} {
-	puts stderr "LayoutFrameInfoBox"
+	puts stderr "LayoutFrameInfoBox $which $type"
     }
 
-    switch -- $which {
-	base {
-	    grid forget $ds9(info).valueRTitle $ds9(info).valueR \
-		$ds9(info).valueGTitle $ds9(info).valueG \
-		$ds9(info).valueBTitle $ds9(info).valueB
-
-	    switch -- $view(layout) {
-		vertical {
-		    grid $ds9(info).value \
-			-row $ds9(info,row,value) \
-			-column 1 -padx 2 -sticky w
-		}
-		horizontal {
-		    grid $ds9(info).value \
-			-row $ds9(info,row,value) \
-			-column 2 -padx 2 -sticky w
-		}
-	    }
-
-	    foreach ll {{} a b c d e f g h i j k l m n o p q r s t u v w x y z} {
-		grid forget $ds9(info).wcsZLabel$ll
-		grid forget $ds9(info).wcsZValue$ll
-	    }
-	    grid forget $ds9(info).detectorZLabel $ds9(info).detectorZValue
-	    grid forget $ds9(info).amplifierZLabel $ds9(info).amplifierZValue
-	    grid forget $ds9(info).physicalZLabel $ds9(info).physicalZValue
-	    grid forget $ds9(info).imageZLabel $ds9(info).imageZValue
+    switch -- $view(layout) {
+	horizontal {
+	    LayoutFrameInfoBoxHorzValue $which $type
+	    LayoutFrameInfoBoxHorzWCS $which $type
+	    LayoutFrameInfoBoxHorzImage $which $type
 	}
-	rgb {
-	    grid forget $ds9(info).value
-	    switch $view(layout) {
-		vertical {
-		    grid $ds9(info).valueRTitle \
-			-row $ds9(info,row,value,red) \
-			-column 0 -sticky w
-		    grid $ds9(info).valueR -row $ds9(info,row,value,red) \
-			-column 1 -padx 2 -sticky w
-		    grid $ds9(info).valueGTitle \
-			-row $ds9(info,row,value,green) \
-			-column 0 -sticky w
-		    grid $ds9(info).valueG \
-			-row $ds9(info,row,value,green) \
-			-column 1 -padx 2 -sticky w
-		    grid $ds9(info).valueBTitle \
-			-row $ds9(info,row,value,blue) \
-			-column 0 -sticky w
-		    grid $ds9(info).valueB \
-			-row $ds9(info,row,value,blue) \
-			-column 1 -padx 2 -sticky w
-		}
-		horizontal {
-		    grid $ds9(info).valueRTitle \
-			-row $ds9(info,row,value,red) \
-			-column 1 -sticky w
-		    grid $ds9(info).valueR \
-			-row $ds9(info,row,value,red) \
-			-column 2 -padx 2 -sticky w
-		    grid $ds9(info).valueGTitle \
-			-row $ds9(info,row,value,green) \
-			-column 3 -sticky w
-		    grid $ds9(info).valueG \
-			-row $ds9(info,row,value,green) \
-			-column 4 -padx 2 -sticky w
-		    grid $ds9(info).valueBTitle \
-			-row $ds9(info,row,value,blue) \
-			-column 5 -sticky w
-		    grid $ds9(info).valueB \
-			-row $ds9(info,row,value,blue) \
-			-column 6 -padx 2 -sticky w
-		}
-	    }
-	    foreach ll {{} a b c d e f g h i j k l m n o p q r s t u v w x y z} {
-		grid forget $ds9(info).wcsZLabel$ll
-		grid forget $ds9(info).wcsZValue$ll
-	    }
-	    grid forget $ds9(info).detectorZLabel $ds9(info).detectorZValue
-	    grid forget $ds9(info).amplifierZLabel $ds9(info).amplifierZValue
-	    grid forget $ds9(info).physicalZLabel $ds9(info).physicalZValue
-	    grid forget $ds9(info).imageZLabel $ds9(info).imageZValue
+	vertical {
+	    LayoutFrameInfoBoxVertValue $which $type
+	    LayoutFrameInfoBoxVertWCS $which $type
+	    LayoutFrameInfoBoxVertImage $which $type
 	}
+    }
+}
+
+proc LayoutFrameInfoBoxHorzValue {which type} {
+    global ds9
+
+    switch -- $type {
+	base -
 	3d {
 	    grid forget $ds9(info).valueRTitle $ds9(info).valueR \
 		$ds9(info).valueGTitle $ds9(info).valueG \
 		$ds9(info).valueBTitle $ds9(info).valueB
 
-	    switch -- $view(layout) {
-		vertical {
-		    grid $ds9(info).value -row $ds9(info,row,value) \
-			-column 1 -padx 2 -sticky w
+	    grid $ds9(info).value -row $ds9(info,row,value) \
+		-column 2 -padx 2 -sticky w
+	}
+	rgb {
+	    grid forget $ds9(info).value
 
-		    foreach ll {{} a b c d e f g h i j 
-			k l m n o p q r s t u v w x y z} {
-			if {$view(info,wcs$ll)} {
-			    grid $ds9(info).wcsZLabel$ll \
-				-row $ds9(info,row,wcs$ll) \
-				-column 0 -sticky w
-			    grid $ds9(info).wcsZValue$ll \
-				-row $ds9(info,row,wcs$ll) \
-				-column 1 -padx 2
-			    incr row
-			} else {
-			    grid forget $ds9(info).wcsZLabel$ll
-			    grid forget $ds9(info).wcsZValue$ll
-			}
-		    }
+	    grid $ds9(info).valueRTitle -row $ds9(info,row,value,red) \
+		-column 1 -sticky w
+	    grid $ds9(info).valueR -row $ds9(info,row,value,red) \
+		-column 2 -padx 2 -sticky w
+	    grid $ds9(info).valueGTitle -row $ds9(info,row,value,green) \
+		-column 3 -sticky w
+	    grid $ds9(info).valueG -row $ds9(info,row,value,green) \
+		-column 4 -padx 2 -sticky w
+	    grid $ds9(info).valueBTitle -row $ds9(info,row,value,blue) \
+		-column 5 -sticky w
+	    grid $ds9(info).valueB -row $ds9(info,row,value,blue) \
+		-column 6 -padx 2 -sticky w
+	}
+    }
+}
 
-		    if {$view(info,detector)} {
-			grid $ds9(info).detectorZLabel \
-			    -row $ds9(info,row,detector) \
-			    -column 0 -sticky w
-			grid $ds9(info).detectorZValue \
-			    -row $ds9(info,row,detector) \
-			    -column 1 -padx 2
-		    } else {
-			grid forget $ds9(info).detectorZLabel \
-			    $ds9(info).detectorZValue
-		    }
-		    if {$view(info,amplifier)} {
-			grid $ds9(info).amplifierZLabel \
-			    -row $ds9(info,row,amplifier) \
-			    -column 0 -sticky w
-			grid $ds9(info).amplifierZValue \
-			    -row $ds9(info,row,amplifier) \
-			    -column 1 -padx 2
-		    } else {
-			grid forget $ds9(info).amplifierZLabel \
-			    $ds9(info).amplifierZValue
-		    }
-		    if {$view(info,physical)} {
-			grid $ds9(info).physicalZLabel \
-			    -row $ds9(info,row,physical) \
-			    -column 0 -sticky w
-			grid $ds9(info).physicalZValue \
-			    -row $ds9(info,row,physical) \
-			    -column 1 -padx 2
-		    } else {
-			grid forget $ds9(info).physicalZLabel \
-			    $ds9(info).physicalZValue
-		    }
-		    if {$view(info,image)} {
-			grid $ds9(info).imageZLabel \
-			    -row $ds9(info,row,image) \
-			    -column 0 -sticky w
-			grid $ds9(info).imageZValue \
-			    -row $ds9(info,row,image) \
-			    -column 1 -padx 2
-		    } else {
-			grid forget $ds9(info).imageZLabel \
-			    $ds9(info).imageZValue
-		    }
+proc LayoutFrameInfoBoxHorzWCS {which type} {
+    global ds9
+    global view
+
+    foreach ll {{} a b c d e f g h i j k l m n o p q r s t u v w x y z} {
+	if {$which != {} && $view(info,wcs$ll)} {
+	    if {[$which has wcs 3d wcs$ll]} {
+		grid $ds9(info).wcsZLabel$ll -row $ds9(info,row,wcs$ll)\
+		    -column 5 -sticky w
+		grid $ds9(info).wcsZValue$ll -row $ds9(info,row,wcs$ll)\
+		    -column 6 -padx 2
+		incr row
+	    } else {
+		grid forget $ds9(info).wcsZLabel$ll \
+		    $ds9(info).wcsZValue$ll
+	    }
+	} else {
+	    grid forget $ds9(info).wcsZLabel$ll $ds9(info).wcsZValue$ll
+	}
+    }
+}
+
+proc LayoutFrameInfoBoxHorzImage {which type} {
+    global ds9
+    global view
+
+    switch $type {
+	base -
+	rgb {
+	    if {$which != {} && $view(info,image)} {
+		if {[$which has fits cube]} {
+		    grid $ds9(info).imageZLabel \
+			-row $ds9(info,row,image) -column 5 -sticky w
+		    grid $ds9(info).imageZValue \
+			-row $ds9(info,row,image) -column 6 -padx 2
+		} else {
+		    grid forget $ds9(info).imageZLabel $ds9(info).imageZValue
 		}
-		horizontal {
-		    grid $ds9(info).value -row $ds9(info,row,value) \
-			-column 2 -padx 2 -sticky w
+	    } else {
+		grid forget $ds9(info).imageZLabel $ds9(info).imageZValue
+	    }
+	}
+	3d {
+	    if {$view(info,image)} {
+		grid $ds9(info).imageZLabel \
+		    -row $ds9(info,row,image) -column 5 -sticky w
+		grid $ds9(info).imageZValue \
+		    -row $ds9(info,row,image) -column 6 -padx 2
+	    } else {
+		grid forget $ds9(info).imageZLabel $ds9(info).imageZValue
+	    }
+	}
+    }
+}
 
-		    foreach ll {{} a b c d e f g h i j 
-			k l m n o p q r s t u v w x y z} {
-			if {$view(info,wcs$ll)} {
-			    grid $ds9(info).wcsZLabel$ll \
-				-row $ds9(info,row,wcs$ll) \
-				-column 5 -sticky w
-			    grid $ds9(info).wcsZValue$ll \
-				-row $ds9(info,row,wcs$ll) \
-				-column 6 -padx 2
-			    incr row
-			} else {
-			    grid forget $ds9(info).wcsZLabel$ll
-			    grid forget $ds9(info).wcsZValue$ll
-			}
-		    }
+proc LayoutFrameInfoBoxVertValue {which type} {
+    global ds9
 
-		    if {$view(info,detector)} {
-			grid $ds9(info).detectorZLabel \
-			    -row $ds9(info,row,detector) \
-			    -column 5 -sticky w
-			grid $ds9(info).detectorZValue \
-			    -row $ds9(info,row,detector) \
-			    -column 6 -padx 2
-		    } else {
-			grid forget $ds9(info).detectorZLabel \
-			    $ds9(info).detectorZValue
-		    }
-		    if {$view(info,amplifier)} {
-			grid $ds9(info).amplifierZLabel \
-			    -row $ds9(info,row,amplifier) \
-			    -column 5 -sticky w
-			grid $ds9(info).amplifierZValue \
-			    -row $ds9(info,row,amplifier) \
-			    -column 6 -padx 2
-		    } else {
-			grid forget $ds9(info).amplifierZLabel \
-			    $ds9(info).amplifierZValue
-		    }
-		    if {$view(info,physical)} {
-			grid $ds9(info).physicalZLabel \
-			    -row $ds9(info,row,physical) \
-			    -column 5 -sticky w
-			grid $ds9(info).physicalZValue \
-			    -row $ds9(info,row,physical) \
-			    -column 6 -padx 2
-		    } else {
-			grid forget $ds9(info).physicalZLabel \
-			    $ds9(info).physicalZValue
-		    }
-		    if {$view(info,image)} {
-			grid $ds9(info).imageZLabel \
-			    -row $ds9(info,row,image) \
-			    -column 5 -sticky w
-			grid $ds9(info).imageZValue \
-			    -row $ds9(info,row,image) \
-			    -column 6 -padx 2
-		    } else {
-			grid forget $ds9(info).imageZLabel \
-			    $ds9(info).imageZValue
-		    }
+    switch -- $type {
+	base -
+	3d {
+	    grid forget $ds9(info).valueRTitle $ds9(info).valueR \
+		$ds9(info).valueGTitle $ds9(info).valueG \
+		$ds9(info).valueBTitle $ds9(info).valueB
+
+	    grid $ds9(info).value -row $ds9(info,row,value) \
+		-column 1 -padx 2 -sticky w
+	}
+	rgb {
+	    grid forget $ds9(info).value
+
+	    grid $ds9(info).valueRTitle -row $ds9(info,row,value,red) \
+		-column 0 -sticky w
+	    grid $ds9(info).valueR -row $ds9(info,row,value,red) \
+		-column 1 -padx 2 -sticky w
+	    grid $ds9(info).valueGTitle -row $ds9(info,row,value,green) \
+		-column 0 -sticky w
+	    grid $ds9(info).valueG -row $ds9(info,row,value,green) \
+		-column 1 -padx 2 -sticky w
+	    grid $ds9(info).valueBTitle -row $ds9(info,row,value,blue) \
+		-column 0 -sticky w
+	    grid $ds9(info).valueB -row $ds9(info,row,value,blue) \
+		-column 1 -padx 2 -sticky w
+	}
+    }
+}
+
+proc LayoutFrameInfoBoxVertWCS {which type} {
+    global ds9
+    global view
+
+    foreach ll {{} a b c d e f g h i j k l m n o p q r s t u v w x y z} {
+	if {$which != {} && $view(info,wcs$ll)} {
+	    if {[$which has wcs 3d wcs$ll]} {
+		grid $ds9(info).wcsZLabel$ll -row $ds9(info,row,wcs$ll)\
+		    -column 0 -sticky w
+		grid $ds9(info).wcsZValue$ll -row $ds9(info,row,wcs$ll)\
+		    -column 1 -padx 2
+		incr row
+	    } else {
+		grid forget $ds9(info).wcsZLabel$ll $ds9(info).wcsZValue$ll
+	    }
+	} else {
+	    grid forget $ds9(info).wcsZLabel$ll $ds9(info).wcsZValue$ll
+	}
+    }
+}
+
+proc LayoutFrameInfoBoxVertImage {which type} {
+    global ds9
+    global view
+
+    switch $type {
+	base -
+	rgb {
+	    if {$which != {} && $view(info,image)} {
+		if {[$which has fits cube]} {
+		    grid $ds9(info).imageZLabel -row $ds9(info,row,image) \
+			-column 0 -sticky w
+		    grid $ds9(info).imageZValue -row $ds9(info,row,image) \
+			-column 1 -padx 2
+		} else {
+		    grid forget $ds9(info).imageZLabel $ds9(info).imageZValue
 		}
+	    } else {
+		grid forget $ds9(info).imageZLabel $ds9(info).imageZValue
+	    }
+	}
+	3d {
+	    if {$view(info,image)} {
+		grid $ds9(info).imageZLabel -row $ds9(info,row,image) \
+		    -column 0 -sticky w
+		grid $ds9(info).imageZValue -row $ds9(info,row,image) \
+		    -column 1 -padx 2
+	    } else {
+		grid forget $ds9(info).imageZLabel $ds9(info).imageZValue
 	    }
 	}
     }
@@ -386,7 +342,7 @@ proc EnterInfoBox {which} {
 	puts stderr "EnterInfoBox $which"
     }
 
-    LayoutFrameInfoBox [$which get type]
+    LayoutFrameInfoBox $which [$which get type]
     LayoutWCSInfoBox $which
 
     set infobox(frame) "[msgcat::mc {Frame}] [string range $which 5 end]"
@@ -505,7 +461,8 @@ proc RefreshInfoBox {which} {
 	    crop -
 	    catalog -
 	    examine -
-	    iexam {
+	    iexam -
+	    3d {
 		EnterInfoBox $which
 		UpdateInfoBoxFrame $which
 	    }
@@ -618,6 +575,7 @@ proc LayoutInfoPanel {} {
 proc LayoutInfoPanelHorz {} {
     global ds9
     global view
+    global current
 
     set ww 12
     set row 0
@@ -738,7 +696,6 @@ proc LayoutInfoPanelHorz {} {
     set ds9(info,row,value,green) $row
     set ds9(info,row,value,blue) $row
     incr row
-    LayoutFrameInfoBox base
 
     # unit
     if {$view(info,bunit)} {
@@ -780,7 +737,6 @@ proc LayoutInfoPanelHorz {} {
     if {$view(info,detector)} {
 	$ds9(info).detectorXValue configure -width $ww
 	$ds9(info).detectorYValue configure -width $ww
-	$ds9(info).detectorZValue configure -width $ww
 
 	grid $ds9(info).detectorTitle  -row $row -column 0 -sticky w
 	grid $ds9(info).detectorXLabel -row $row -column 1 -sticky w
@@ -801,7 +757,6 @@ proc LayoutInfoPanelHorz {} {
     if {$view(info,amplifier)} {
 	$ds9(info).amplifierXValue configure -width $ww
 	$ds9(info).amplifierYValue configure -width $ww
-	$ds9(info).amplifierZValue configure -width $ww
 
 	grid $ds9(info).amplifierTitle  -row $row -column 0 -sticky w
 	grid $ds9(info).amplifierXLabel -row $row -column 1 -sticky w
@@ -822,7 +777,6 @@ proc LayoutInfoPanelHorz {} {
     if {$view(info,physical)} {
 	$ds9(info).physicalXValue configure -width $ww
 	$ds9(info).physicalYValue configure -width $ww 
-	$ds9(info).physicalZValue configure -width $ww 
 
 	grid $ds9(info).physicalTitle  -row $row -column 0 -sticky w
 	grid $ds9(info).physicalXLabel -row $row -column 1 -sticky w
@@ -860,6 +814,8 @@ proc LayoutInfoPanelHorz {} {
 	grid forget $ds9(info).imageYValue
     }
 
+    LayoutFrameInfoBox $current(frame) base
+
     # frame, zoom, angle
     if {$view(info,frame)} {
 	$ds9(info).zoomValue configure -width $ww
@@ -886,6 +842,7 @@ proc LayoutInfoPanelHorz {} {
 proc LayoutInfoPanelVert {} {
     global ds9
     global view
+    global current
 
     set ww 13
     set row 0
@@ -1005,8 +962,7 @@ proc LayoutInfoPanelVert {} {
     incr row
     set ds9(info,row,value,blue) $row
     incr row
-    LayoutFrameInfoBox base
-
+    
     # units
     if {$view(info,bunit)} {
 	$ds9(info).bunitValue configure -width $ww
@@ -1051,7 +1007,6 @@ proc LayoutInfoPanelVert {} {
     if {$view(info,detector)} {
 	$ds9(info).detectorXValue configure -width $ww
 	$ds9(info).detectorYValue configure -width $ww
-	$ds9(info).detectorZValue configure -width $ww
 
 	grid $ds9(info).detectorTitle  -row $row -column 1 -sticky ew
 	incr row
@@ -1075,7 +1030,6 @@ proc LayoutInfoPanelVert {} {
     if {$view(info,amplifier)} {
 	$ds9(info).amplifierXValue configure -width $ww
 	$ds9(info).amplifierYValue configure -width $ww
-	$ds9(info).amplifierZValue configure -width $ww
 
 	grid $ds9(info).amplifierTitle  -row $row -column 1 -sticky ew
 	incr row
@@ -1099,7 +1053,6 @@ proc LayoutInfoPanelVert {} {
     if {$view(info,physical)} {
 	$ds9(info).physicalXValue configure -width $ww
 	$ds9(info).physicalYValue configure -width $ww 
-	$ds9(info).physicalZValue configure -width $ww 
 
 	grid $ds9(info).physicalTitle  -row $row -column 1 -sticky ew
 	incr row
@@ -1143,6 +1096,8 @@ proc LayoutInfoPanelVert {} {
 	grid forget $ds9(info).imageYValue
     }
 
+    LayoutFrameInfoBox $current(frame) base
+
     # frame, zoom, angle
     if {$view(info,frame)} {
 	$ds9(info).zoomValue configure -width $ww
