@@ -81,7 +81,7 @@ proc MarkerAnalysisPlot3dMethod {varname} {
     if {[info exists var(plot3d)]} {
 	if {$var(plot3d)} {
 	    MarkerAnalysisPlot3dCB $frame $id
-	    MarkerAnalysisPlot3dYAxisTitle $vvarname
+	    MarkerAnalysisPlot3dAxisTitle $vvarname
 	}
     }
 }
@@ -102,7 +102,7 @@ proc MarkerAnalysisPlot3dSystem {varname} {
     if {[info exists var(plot3d)]} {
 	if {$var(plot3d)} {
 	    MarkerAnalysisPlot3dCB $frame $id
-	    MarkerAnalysisPlot3dXAxisTitle $vvarname
+	    MarkerAnalysisPlot3dAxisTitle $vvarname
 	}
     }
 }
@@ -130,13 +130,6 @@ proc MarkerAnalysisPlot3dCB {frame id} {
 	set vvar(system) $wcs(system)
     }
 
-    if {[info exists var(sky)]} {
-	set vvar(sky) $var(sky)
-    } elseif {[info exists vvar(sky)]} {
-    } else {
-	set vvar(sky) $wcs(sky)
-    }
-
     if {[info exists var(method)]} {
 	set vvar(method) $var(method)
     } elseif {[info exists vvar(method)]} {
@@ -144,113 +137,53 @@ proc MarkerAnalysisPlot3dCB {frame id} {
 	set vvar(method) average
     }
 
-    set xdata ${vvarname}x
-    set ydata ${vvarname}y
+    # sanity check
+    if {![$frame has wcs 3d $vvar(system)]} {
+	set vvar(system) image
+    }
+
+    set xdata ${vvarname}xx
+    set ydata ${vvarname}yy
     global $xdata $ydata
 
-    set ping [PlotPing $vvarname]
-
-    if {!$ping} {
-	set tt [string totitle [$frame get marker $id type]]
+    if {[info command $xdata] == {}} {
+	blt::vector create $xdata $ydata
+    }
+    $frame get marker $id analysis plot3d $xdata $ydata \
+	$vvar(system) $vvar(method)
+    
+    if {![PlotPing $vvarname]} {
 	set vvar(bunit) [string trim [$frame get fits header keyword BUNIT]]
 	if {$vvar(bunit)=={}} {
 	    set vvar(bunit) {Counts}
 	}
-	PlotLineDialog $vvarname $tt {} $vvar(system) $vvar(bunit)
-	MarkerAnalysisPlot3dXAxisTitle $vvarname
-	MarkerAnalysisPlot3dYAxisTitle $vvarname
+	PlotDialog $vvarname [string totitle [$frame get marker $id type]]
+	PlotAddGraph $vvarname line
+
+	MarkerAnalysisPlot3dAxisTitle $vvarname
 
 	set vvar(markerslice) [$vvar(graph) marker create line -element bar1 \
 			     -outline cyan -linewidth 2 \
 			     -bindtags [list slice]]
+	$vvar(graph) configure -halo 10
 	$vvar(graph) marker bind slice <B1-Motion> \
 	    [list MarkerAnalysisPlot3dMotion $vvarname %x %y]
 
 	set vvar(mode) pointer
 	PlotChangeMode $vvarname
 
-	set vvar(manage) 0
-	set vvar(dim) xy
-	set vvar(xdata) $xdata
-	set vvar(ydata) $ydata
-	blt::vector create $xdata $ydata
+	set vvar(graph,ds,xdata) $xdata
+	set vvar(graph,ds,ydata) $ydata
+	PlotExternal $vvarname xy
     }
 
-    $frame get marker $id analysis plot3d $xdata $ydata \
-	$vvar(system) $vvar(sky) $vvar(method)
-
-    set vvar(slice) [$frame get fits slice from image $vvar(system) $vvar(sky)]
+    set vvar(slice) [$frame get fits slice from image $vvar(system)]
     MarkerAnalysisPlot3dMarker $vvarname
 
-    if {!$ping} {
-	PlotExternal $vvarname
-	$vvar(proc,updateelement) $vvarname
-	$vvar(proc,updategraph) $vvarname
-    }
-
     PlotStats $vvarname
     PlotList $vvarname
 }
 
-proc MarkerAnalysisPlot3dMotion {vvarname xx yy} {
-    upvar #0 $vvarname vvar
-    global $vvarname
-
-    if {$vvar(mode) != "pointer"} {
-	return
-    }
-
-    set vvar(slice) [lindex [$vvar(graph) invtransform $xx $yy] 0]
-    $vvar(frame) update fits slice $vvar(slice) $vvar(system) $vvar(sky)
-
-    MarkerAnalysisPlot3dMarker $vvarname
-
-    # current frame only
-    global current
-    if {$vvar(frame) == $current(frame)} {
-	UpdateCubeMotionDialog
-	UpdateScaleDialog
-	UpdateContourScale
-	UpdateContourDialog
-    }
-}
-
-proc MarkerAnalysisPlot3dMarker {vvarname} {
-    upvar #0 $vvarname vvar
-    global $vvarname
-
-    set ss [$vvar(frame) get crop 3d $vvar(system) $vvar(sky)]
-    set min [lindex $ss 0]
-    set max [lindex $ss 1]
-    set delta [expr ($max-$min)*.0001]
-    if {[::math::fuzzy::tle $vvar(slice) $min]} {
-	set vvar(slice) [expr $min+$delta]
-    }
-    if {[::math::fuzzy::tge $vvar(slice) $max]} {
-	set vvar(slice) [expr $max-$delta]
-    }
-    $vvar(graph) marker configure $vvar(markerslice) \
-	-coords "$vvar(slice) -Inf $vvar(slice) Inf"
-}
-
-# hardcoded marker.C
-proc MarkerAnalysisPlot3dSliceCB {frame id} {
-    global imarker
-
-    set vvarname ${imarker(prefix,plot3d)}${id}${frame}
-    upvar #0 $vvarname vvar
-    global $vvarname
-
-    # if the plot is destroyed, but marker still thinks it is good
-    # this routine will be called, so check first
-
-    if {[info exists ${vvarname}(system)]} {
-	set vvar(slice) \
-	    [$frame get fits slice from image $vvar(system) $vvar(sky)]
-	MarkerAnalysisPlot3dMarker $vvarname
-    }
-}
-
 # hardcoded marker.C
 proc MarkerAnalysisPlot3dDeleteCB {frame id} {
     # this routine could be called by the region 
@@ -269,7 +202,61 @@ proc MarkerAnalysisPlot3dDeleteCB {frame id} {
     PlotDestroy $vvarname
 }
 
-proc MarkerAnalysisPlot3dXAxisTitle {vvarname} {
+# hardcoded marker.C
+proc MarkerAnalysisPlot3dSliceCB {frame id} {
+    global imarker
+
+    set vvarname ${imarker(prefix,plot3d)}${id}${frame}
+    upvar #0 $vvarname vvar
+    global $vvarname
+
+    # if the plot is destroyed, but marker still thinks it is good
+    # this routine will be called, so check first
+
+    if {[info exists ${vvarname}(system)]} {
+	set vvar(slice) \
+	    [$frame get fits slice from image $vvar(system)]
+	MarkerAnalysisPlot3dMarker $vvarname
+    }
+}
+
+proc MarkerAnalysisPlot3dMotion {vvarname xx yy} {
+    upvar #0 $vvarname vvar
+    global $vvarname
+
+    if {$vvar(mode) != "pointer"} {
+	return
+    }
+
+    set cc 1
+    if {[info exists vvar($cc,graph)]} {
+	set vvar(slice) [lindex [$vvar($cc,graph) invtransform $xx $yy] 0]
+	$vvar(frame) update fits slice $vvar(slice) $vvar(system)
+	MarkerAnalysisPlot3dMarker $vvarname
+    }
+
+    # current frame only
+    global current
+    if {$vvar(frame) == $current(frame)} {
+	UpdateCubeMotionDialog
+	UpdateScaleDialog
+	UpdateContourScale
+	UpdateContourDialog
+    }
+}
+
+proc MarkerAnalysisPlot3dMarker {vvarname} {
+    upvar #0 $vvarname vvar
+    global $vvarname
+
+    set cc 1
+    if {[info exists vvar($cc,graph)]} {
+	$vvar($cc,graph) marker configure $vvar(markerslice) \
+	    -coords "$vvar(slice) -Inf $vvar(slice) Inf"
+    }
+}
+
+proc MarkerAnalysisPlot3dAxisTitle {vvarname} {
     upvar #0 $vvarname vvar
     global $vvarname
 
@@ -289,20 +276,7 @@ proc MarkerAnalysisPlot3dXAxisTitle {vvarname} {
 	}
     }
 
-    # set for plot code
-    set vvar(axis,x,title) $xtitle
+    set ytitle "$vvar(bunit) [string totitle $vvar(method)]"
 
-    # update now (may not make it into plot code)
-    $vvar(graph) xaxis configure -title $xtitle
-}
-
-proc MarkerAnalysisPlot3dYAxisTitle {vvarname} {
-    upvar #0 $vvarname vvar
-    global $vvarname
-
-    # set for plot code
-    set vvar(axis,y,title) "$vvar(bunit) [string totitle $vvar(method)]"
-
-    # update now (may not make it into plot code)
-    $vvar(graph) yaxis configure -title $vvar(axis,y,title)
+    PlotTitle $vvarname {} $xtitle $ytitle
 }
