@@ -72,6 +72,7 @@ proc CoordMenu {w varname system other sky skyformat cmd} {
     }
 
     switch -- $other {
+	0 {}
 	1 {
 	    $w add separator
 	    $w add radiobutton -label [msgcat::mc {Image}] \
@@ -152,7 +153,7 @@ proc CoordMenuButtonCmd {varname system sky cmd} {
     }
 }
 
-proc CoordMenuEnable {w varname system image sky skyformat} {
+proc CoordMenuEnable {w varname system sky skyformat} {
     upvar #0 $varname var
     global $varname
     
@@ -180,13 +181,6 @@ proc CoordMenuEnable {w varname system image sky skyformat} {
 	}
     }
 
-    if {$image != {}} {
-	$w entryconfig [msgcat::mc {Image}] -state normal
-	$w entryconfig [msgcat::mc {Physical}] -state normal
-	$w entryconfig [msgcat::mc {Amplifier}] -state normal
-	$w entryconfig [msgcat::mc {Detector}] -state normal
-    }
-
     if {$sky != {}} {
 	if {[$var(frame) has wcs equatorial $var($system)]} {
 	    $w entryconfig [msgcat::mc {FK4}] -state normal
@@ -214,64 +208,7 @@ proc CoordMenuEnable {w varname system image sky skyformat} {
     }
 }
 
-proc CoordMenuEnable3d {w varname system sky skyformat} {
-    upvar #0 $varname var
-    global $varname
-
-    if {![info exists var(frame)]} {
-	return
-    }
-
-    if {$var(frame) == {}} {
-	return
-    }
-
-    if {[$var(frame) has wcs 3d wcs]} {
-	$w entryconfig [msgcat::mc {WCS}] -state normal
-    } else {
-	$w entryconfig [msgcat::mc {WCS}] -state disabled
-    }
-
-    $w entryconfig [msgcat::mc {Multiple WCS}] -state normal
-
-    foreach ll {a b c d e f g h i j k l m n o p q r s t u v w x y z} {
-	if {[$var(frame) has wcs 3d "wcs${ll}"]} {
-	    $w.wcs entryconfig "[msgcat::mc {WCS}] $ll" -state normal
-	} else {
-	    $w.wcs entryconfig "[msgcat::mc {WCS}] $ll" -state disabled
-	}
-    }
-
-    $w entryconfig [msgcat::mc {Image}] -state normal
-
-    if {$sky != {}} {
-	if {[$var(frame) has wcs equatorial $var($system)]} {
-	    $w entryconfig [msgcat::mc {FK4}] -state normal
-	    $w entryconfig [msgcat::mc {FK5}] -state normal
-	    $w entryconfig [msgcat::mc {ICRS}] -state normal
-	    $w entryconfig [msgcat::mc {Galactic}] -state normal
-	    $w entryconfig [msgcat::mc {Ecliptic}] -state normal
-	} else {
-	    $w entryconfig [msgcat::mc {FK4}] -state disabled
-	    $w entryconfig [msgcat::mc {FK5}] -state disabled
-	    $w entryconfig [msgcat::mc {ICRS}] -state disabled
-	    $w entryconfig [msgcat::mc {Galactic}] -state disabled
-	    $w entryconfig [msgcat::mc {Ecliptic}] -state disabled
-	}
-    }
-
-    if {$skyformat != {}} {
-	if {[$var(frame) has wcs celestial $var($system)]} {
-	    $w entryconfig [msgcat::mc {Degrees}] -state normal
-	    $w entryconfig {Sexagesimal} -state normal
-	} else {
-	    $w entryconfig [msgcat::mc {Degrees}] -state disabled
-	    $w entryconfig {Sexagesimal} -state disabled
-	}
-    }
-}
-
-proc CoordMenuReset {w varname system image sky skyformat} {
+proc CoordMenuReset {w varname system sky skyformat} {
     upvar #0 $varname var
     global $varname
 
@@ -282,40 +219,6 @@ proc CoordMenuReset {w varname system image sky skyformat} {
 	$w.wcs entryconfig "[msgcat::mc {WCS}] $l" -state normal
     }
 
-    if {$image != {}} {
-	$w entryconfig [msgcat::mc {Image}] -state normal
-	$w entryconfig [msgcat::mc {Physical}] -state normal
-	$w entryconfig [msgcat::mc {Amplifier}] -state normal
-	$w entryconfig [msgcat::mc {Detector}] -state normal
-    }
-
-    if {$sky != {}} {
-	$w entryconfig [msgcat::mc {FK4}] -state normal
-	$w entryconfig [msgcat::mc {FK5}] -state normal
-	$w entryconfig [msgcat::mc {ICRS}] -state normal
-	$w entryconfig [msgcat::mc {Galactic}] -state normal
-	$w entryconfig [msgcat::mc {Ecliptic}] -state normal
-    }
-
-    if {$skyformat != {}} {
-	$w entryconfig [msgcat::mc {Degrees}] -state normal
-	$w entryconfig {Sexagesimal} -state normal
-    }
-}
-
-proc CoordMenuReset3d {w varname system sky skyformat} {
-    upvar #0 $varname var
-    global $varname
-
-    $w entryconfig [msgcat::mc {WCS}] -state normal
-    $w entryconfig [msgcat::mc {Multiple WCS}] -state normal
-
-    foreach l {a b c d e f g h i j k l m n o p q r s t u v w x y z} {
-	$w.wcs entryconfig "[msgcat::mc {WCS}] $l" -state normal
-    }
-
-    $w entryconfig [msgcat::mc {Image}] -state normal
-
     if {$sky != {}} {
 	$w entryconfig [msgcat::mc {FK4}] -state normal
 	$w entryconfig [msgcat::mc {FK5}] -state normal
@@ -408,7 +311,7 @@ proc DistMenuButtonCmd {varname system format cmd} {
     }
 }
 
-proc DistMenuEnable {w varname system other format} {
+proc DistMenuEnable {w varname system format} {
     upvar #0 $varname var
     global $varname
     
@@ -436,13 +339,6 @@ proc DistMenuEnable {w varname system other format} {
 	}
     }
 
-    if {$other} {
-	$w entryconfig [msgcat::mc {Image}] -state normal
-	$w entryconfig [msgcat::mc {Physical}] -state normal
-	$w entryconfig [msgcat::mc {Amplifier}] -state normal
-	$w entryconfig [msgcat::mc {Detector}] -state normal
-    }
-
     if {$format != {}} {
 	if {[$var(frame) has wcs celestial $var($system)]} {
 	    $w entryconfig [msgcat::mc {Degrees}] -state normal
@@ -456,7 +352,7 @@ proc DistMenuEnable {w varname system other format} {
     }
 }
 
-proc DistMenuReset {w varname system other format} {
+proc DistMenuReset {w varname system format} {
     upvar #0 $varname var
     global $varname
     
@@ -467,13 +363,6 @@ proc DistMenuReset {w varname system other format} {
 	$w.wcs entryconfig "[msgcat::mc {WCS}] $ll" -state normal
     }
 
-    if {$other} {
-	$w entryconfig [msgcat::mc {Image}] -state normal
-	$w entryconfig [msgcat::mc {Physical}] -state normal
-	$w entryconfig [msgcat::mc {Amplifier}] -state normal
-	$w entryconfig [msgcat::mc {Detector}] -state normal
-    }
-
     if {$format != {}} {
 	$w entryconfig [msgcat::mc {Degrees}] -state normal
 	$w entryconfig [msgcat::mc {ArcMin}] -state normal
@@ -658,3 +547,12 @@ proc PrefsDialogMenu {} {
     PrefsDialogHelpMenu $w.menu
 }
 
+proc ConfigureButtons {menu state} {
+    global ds9
+    global pbuttons
+
+    foreach aa [array names pbuttons "$menu,*"] {
+	set bb [lindex [split $aa {,}] 1]
+	$ds9(buttons).$menu.$bb configure -state $state
+    }
+}
