@@ -13,9 +13,8 @@ proc MovieDef {} {
     set imovie(top) .moviestatus
     set imovie(mb) .moviestatusmb
 
+    set movie(type) gif
     set movie(action) slice
-    # must be >=5, or sometimes will generate bad data
-    set movie(quality) 5
     set movie(num) 24
     set movie(az,from) 45
     set movie(az,to) -45
@@ -29,25 +28,13 @@ proc MovieDef {} {
     set movie(status) 0
     set movie(abort) 0
 
-    set aa [msgcat::mc {An error has occurred while creating the image. Please be sure that the entire image window is visible on the screen.}]
-    set bb [msgcat::mc {An error has occurred while creating the image. Please be sure that the ds9 window is in the upper left corner of the default screen and the entire window is visible.}]
-    switch $tcl_platform(os) {
-	Darwin {
-	    switch [lindex [split $tcl_platform(osVersion) {.}] 0] {
-		10 -
-		11 {set movie(error) $bb}
-		8 -
-		9 -
-		default {set movie(error) $aa}
-	    }
-	}
-	default {set movie(error) $aa}
-    }
+    set movie(error) [msgcat::mc {An error has occurred while creating the image. Please be sure that the ds9 window is in the upper left corner of the default screen and the entire window is visible.}]
 }
 
 proc MovieDialog {} {
     global movie
     global mpegfbox
+    global giffbox
     global ed
     global current
 
@@ -55,16 +42,30 @@ proc MovieDialog {} {
 
     set ed(ok) 0
     set ed(action) $movie(action)
+    set ed(type) $movie(type)
 
     DialogCreate $w [msgcat::mc {Create Movie}] ed(ok)
 
+    # Type of Movie
+    set f [ttk::labelframe $w.type -text [msgcat::mc {Type}]]
+
+    ttk::label $f.title -text [msgcat::mc {Type}]
+    ttk::radiobutton $f.mpeg -text {MPEG} \
+	-variable ed(type) -value mpeg
+    ttk::radiobutton $f.gif -text {Animated Gif} \
+	-variable ed(type) -value gif
+
+    grid $f.mpeg -padx 2 -pady 2 -sticky w
+    grid $f.gif -padx 2 -pady 2 -sticky w
+
     # Param
-    set f [ttk::frame $w.param]
+    set f [ttk::labelframe $w.param -text [msgcat::mc {Format}]]
+
     ttk::label $f.title -text [msgcat::mc {Format}]
-    ttk::radiobutton $f.slice -text {Slice Movie} \
-	-variable ed(action) -value slice
     ttk::radiobutton $f.frame -text {Frames Movie} \
 	-variable ed(action) -value frame
+    ttk::radiobutton $f.slice -text {Slice Movie} \
+	-variable ed(action) -value slice
     ttk::radiobutton $f.3d -text {3D Movie} \
 	-variable ed(action) -value 3d
 
@@ -88,9 +89,12 @@ proc MovieDialog {} {
     bind $w <Return> {set ed(ok) 1}
 
     # Fini
-    ttk::separator $w.sep -orient horizontal
-    pack $w.buttons $w.sep -side bottom -fill x
-    pack $w.param -side top -fill both -expand true
+    grid $w.type -sticky news
+    grid $w.param -sticky news
+    grid $w.buttons -sticky ew
+    grid rowconfigure $w 0 -weight 1
+    grid rowconfigure $w 1 -weight 1
+    grid columnconfigure $w 0 -weight 1
 
     DialogCenter $w 
     DialogWait $w ed(ok)
@@ -98,7 +102,12 @@ proc MovieDialog {} {
 
     if {$ed(ok)} {
 	set movie(action) $ed(action)
- 	set fn [SaveFileDialog mpegfbox]
+	set movie(type) $ed(type)
+
+	switch $movie(type) {
+	    mpeg {set fn [SaveFileDialog mpegfbox]}
+	    gif {set fn [SaveFileDialog giffbox]}
+	}
 
 	if {$fn != {}} {
 	    set ok 1
@@ -109,7 +118,7 @@ proc MovieDialog {} {
 	    }
 
 	    if {$ok} {
-		Movie $fn
+		MovieCreate $fn
 	    }
 	}
     }
@@ -119,7 +128,7 @@ proc MovieDialog {} {
     return $rr
 }
 
-proc Movie {fn} {
+proc MovieCreate {fn} {
     global ds9
     global movie
     global current
@@ -129,15 +138,6 @@ proc Movie {fn} {
 	return
     }
 
-    switch $ds9(wm) {
-	x11 {}
-	aqua -
-	win32 {
-	    Error $saveimage(error)
-	    return
-	}
-    }
-
     # besure we are on top
     raise $ds9(top)
 
@@ -148,19 +148,53 @@ proc Movie {fn} {
 	DisplayMode
     }
 
+    # for darwin only
+    set geom [MacOSPhotoFix $ds9(top) 0 1]
+
+    set movie(fn) $fn
     switch $movie(action) {
-	slice {MovieSlice $fn}
-	frame {MovieFrame $fn}
-	3d {Movie3d $fn}
+	frame {MovieFrame}
+	slice {MovieSlice}
+	3d {Movie3d}
+    }
+
+    # close
+    switch $movie(type) {
+	mpeg {mpeg close}
+	gif {agif close}
     }
 
     if {[info exists modesav]} {
 	set current(display) $modesav
 	DisplayMode
     }
+
+    # reset if needed
+    DarwinPhotoRestore $ds9(top) $geom
 }
 
-proc MovieSlice {fn} {
+proc MovieFrame {} {
+    global ds9
+    global current
+    global movie
+
+    # loop thru all active frames
+    set movie(first) 1
+    set framesav $current(frame)
+
+    foreach ff $ds9(active) {
+	set ds9(next) $ff
+	GotoFrame
+	if {[MoviePhoto]} {
+	    break
+	}
+    }
+
+    set ds9(next) $framesav
+    GotoFrame
+}
+
+proc MovieSlice {} {
     global current
     global movie
 
@@ -175,39 +209,16 @@ proc MovieSlice {fn} {
     set movie(first) 1
     for {set ii $from} {$ii <= $to} {incr ii} {
 	$current(frame) update fits slice $ii
-	if {[MoviePhoto $fn]} {
+	if {[MoviePhoto]} {
 	    break
 	}
     }
-    mpeg close
 
     # reset current slice
     $current(frame) update fits slice $slice
 }
 
-proc MovieFrame {fn} {
-    global ds9
-    global current
-    global movie
-
-    # loop thru all active frames
-    set movie(first) 1
-    set framesav $current(frame)
-
-    foreach ff $ds9(active) {
-	set ds9(next) $ff
-	GotoFrame
-	if {[MoviePhoto $fn]} {
-	    break
-	}
-    }
-    mpeg close
-
-    set ds9(next) $framesav
-    GotoFrame
-}
-
-proc Movie3d {fn} {
+proc Movie3d {} {
     global movie
     global current
 
@@ -239,7 +250,7 @@ proc Movie3d {fn} {
 
 	    $current(frame) 3d view $az $el
 	    $current(frame) update fits slice [expr int($sl)]
-	    if {[MoviePhoto $fn]} {
+	    if {[MoviePhoto]} {
 		break
 	    }
 	    set az [expr $az+$azincr]
@@ -259,7 +270,6 @@ proc Movie3d {fn} {
 	    }
 	}
     }
-    mpeg close
 
     MovieStatusDestroyDialog
 
@@ -272,7 +282,17 @@ proc Movie3d {fn} {
 
 # Support
 
-proc MoviePhoto {fn} {
+proc MoviePhoto {} {
+    global movie
+
+    switch $movie(type) {
+	mpeg {return [MoviePhotoMPEG]}
+	gif {return [MoviePhotoGIF]}
+    }
+    return 1
+}
+
+proc MoviePhotoMPEG {} {
     global ds9
     global movie
     global current
@@ -288,14 +308,41 @@ proc MoviePhoto {fn} {
     }
 
     if {$movie(first)} {
-	set w [image width $ph]
-	set h [image height $ph]
-	mpeg create "$fn" $w $h 25 1 $movie(quality)
+	set ww [image width $ph]
+	set hh [image height $ph]
+	# quality must be >=5, or sometimes will generate bad data
+	mpeg create "$movie(fn)" $ww $hh 25 1 5
 	set movie(first) 0
     }
     mpeg add $ph
-
     image delete $ph
+
+    return 0
+}
+
+proc MoviePhotoGIF {} {
+    global ds9
+    global movie
+    global current
+    global colorbar
+
+    # yes, we need this
+    UpdateDS9
+    RealizeDS9 1
+
+    set rr [catch {image create photo -format window -data $ds9(canvas)} ph]
+    if {$rr} {
+	Error $movie(error)
+	return $rr
+    }
+
+    if {$movie(first)} {
+	agif create $movie(fn) [image width $ph] [image height $ph]
+	set movie(first) 0
+    }
+    agif add $ph
+    image delete $ph
+
     return 0
 }
 
