@@ -305,6 +305,9 @@ proc ScaleDialog {} {
 
     # Graph
     set dscale(hist) [blt::graph $f.chart \
+			  -foreground $ds9(gui,fg) \
+			  -background $ds9(gui,bg) \
+			  -plotbackground $ds9(gui,bg) \
 			  -width 500 \
 			  -height 200 \
 			  -title [msgcat::mc {Pixel Distribution}] \
@@ -314,15 +317,23 @@ proc ScaleDialog {} {
 			 ]
 
     $dscale(hist) legend configure -hide yes
+
     $dscale(hist) xaxis configure -hide yes -grid no -ticklength 3 \
-	-tickfont [font actual TkDefaultFont]
+	-tickfont [font actual TkDefaultFont] \
+	-bg $ds9(gui,bg) -color $ds9(gui,fg) \
+	-titlecolor $ds9(gui,fg)
+
     $dscale(hist) yaxis configure -hide yes -grid yes -ticklength 3 \
-	-tickfont [font actual TkDefaultFont]
+	-tickfont [font actual TkDefaultFont] \
+	-bg $ds9(gui,bg) -color $ds9(gui,fg) \
+	-titlecolor $ds9(gui,fg)
+
     set dscale(xdata) histX
     set dscale(ydata) histY
     blt::vector create $dscale(xdata) $dscale(ydata)
-    $dscale(hist) element create bar1 -smooth step -areabackground black \
-	-xdata $dscale(xdata) -ydata $dscale(ydata)
+    $dscale(hist) element create bar1 -smooth step  \
+	-xdata $dscale(xdata) -ydata $dscale(ydata) \
+	-areabackground $ds9(gui,fg) -color $ds9(gui,fg)
 
     # Cut Lines
     $dscale(hist) marker bind min <B1-Motion> \
