@@ -160,7 +160,8 @@ proc UpdateMain {} {
 	rotate -
 	crop -
 	examine -
-	iexam {}
+	iexam -
+	3d {}
     }
 }
 
@@ -251,6 +252,11 @@ proc ProcessCmdCVAR0 {cmd} {
     eval $cmd $cvarname
 }
 
+proc ProcessCmdCVAROpt {cmd opt} {
+    global cvarname
+    eval $cmd $cvarname {$opt}
+}
+
 proc ProcessCmdCVAR {key value {cmd {}}} {
     global cvarname
     upvar #0 $cvarname cvar
@@ -840,17 +846,8 @@ proc AboutBox {} {
     canvas $f.c -background white -height 450 -width 500
     pack $f.c -fill both -expand true
     
-    # can't use -file for zvfs
-    # set ed(sun) [image create photo -format gif -file $ds9(root)/doc/sun.gif]
-    set ch [open $ds9(root)/doc/sun.gif r]
-    fconfigure $ch -translation binary -encoding binary
-    set dd [read $ch]
-    close $ch
-    unset ch
-
-    set ed(sun) [image create photo -format gif -data "$dd"]
-    unset dd
-
+    set ed(sun) [image create photo -format gif -file $ds9(root)/doc/sun.gif]
+    
     $f.c create image 0 0 -image $ed(sun) -anchor nw
     $f.c create text 120 22 -text $help(about) -anchor nw -width 350
 
@@ -901,6 +898,14 @@ proc QuitDS9 {} {
 	}
     }
 
+    # delete frames
+    # may have regions with plot windows
+    DeleteAllFrames
+
+    # make sure everybody has had a chance to shut down properly
+    update
+
+    # and we are done
     focus {}
     exit
 }
@@ -913,11 +918,25 @@ proc OpenSource {} {
 }
 
 proc OpenConsole {} {
+    global ds9
+    
     if {[winfo exists ".tkcon"]} {
 	tkcon show
     } else {
 	set ::tkcon::OPT(exec) {}
 	set ::tkcon::OPT(font) [font actual TkFixedFont]
+	
+	set ::tkcon::COLOR(bg) $ds9(gui,bg)
+#	set ::tkcon::COLOR(blink) $ds9(gui,fg)
+	set ::tkcon::COLOR(cursor) $ds9(gui,fg)
+#	set ::tkcon::COLOR(disabled) $ds9(gui,bg)
+#	set ::tkcon::COLOR(proc) $ds9(gui,bg)
+#	set ::tkcon::COLOR(var) $ds9(gui,bg)
+	set ::tkcon::COLOR(prompt) $ds9(gui,fg)
+	set ::tkcon::COLOR(stdin) $ds9(gui,fg)
+	set ::tkcon::COLOR(stdout) $ds9(gui,fg)
+	set ::tkcon::COLOR(stderr) $ds9(gui,fg)
+
 	tkcon::Init
     }
 }
@@ -976,6 +995,7 @@ proc ChangeMode {} {
 	crop {SetCursor {}}
 	examine {SetCursor target}
 	iexam {}
+	3d {SetCursor {}}
     }
 }
 
@@ -1136,6 +1156,11 @@ proc ParseURL {url varname} {
     switch $tcl_platform(platform) {
 	unix {
 	    switch -- $r(scheme) {
+		zipfs {
+		    # special case for zipfs
+		    set r(path) "$r(scheme):$r(path)"
+		    set r(scheme) {}
+		}
 		ftp {
 		    # strip any username/passwd
 		    set id [string first {@} $r(authority)]
@@ -1344,6 +1369,42 @@ proc FixSpec {sysname skyname formatname defsys defsky defformat} {
     return $rr
 }
 
+proc MacOSPhotoFix {top xx yy} {
+    global ds9
+    global tcl_platform
+    
+    switch $ds9(wm) {
+	x11 {
+	    if {$tcl_platform(os) == {Darwin}} {
+		set geom [wm geometry $top]
+		wm geometry $top "[lindex [split $geom {+}] 0]+$xx+$yy"
+		update
+		return $geom
+	    }
+	}
+	aqua {macos sc yes}
+	win32 {}
+    }
+    
+    return {}
+}
+
+proc DarwinPhotoRestore {top geom} {
+    global ds9
+    global tcl_platform
+
+    switch $ds9(wm) {
+	x11 {
+	    if {$geom != {} &&
+		$tcl_platform(os) == {Darwin}} {
+		wm geometry $top $geom
+	    }
+	}
+	aqua {macos sc no}
+	win32 {}
+    }
+}
+
 proc DS9Backup {ch which} {
     global pds9
 
@@ -1355,6 +1416,16 @@ proc DS9Backup {ch which} {
 
 # Process Cmds
 
+proc ProcessPrefsFirstCmd {varname iname} {
+    upvar $varname var
+    upvar $iname i
+
+    prefsfirst::YY_FLUSH_BUFFER
+    prefsfirst::yy_scan_string [lrange $var $i end]
+    prefsfirst::yyparse
+    incr i [expr $prefsfirst::yycnt-1]
+}
+
 proc ProcessPrefsCmd {varname iname} {
     upvar $varname var
     upvar $iname i
@@ -1491,7 +1562,8 @@ proc CursorCmd {x y} {
 	rotate -
 	crop -
 	examine -
-	iexam {}
+	iexam -
+	3d {}
     }
 }
 
