@@ -9,6 +9,7 @@
 
 #include "grid2dbase.h"
 #include "vector.h"
+#include "util.h"
 
 class CBGrid : public Grid2dBase {
  private:
@@ -21,7 +22,7 @@ class CBGrid : public Grid2dBase {
   CBGrid(Widget*, int, double*);
 
   int render();
-  int ps(int, int, int);
+  int ps(PSColorSpace, int, int);
 #ifdef MAC_OSX_TK
   int macosx(int, int);
 #endif
