@@ -20,6 +20,7 @@
 #include "tag.h"
 #include "util.h"
 #include "point.h"
+#include "fitsmask.h"
 
 extern int DebugMosaic;
 extern int DebugPerf;
@@ -124,7 +125,7 @@ public:
 
   enum MemType {ALLOC, ALLOCGZ, CHANNEL, MMAP, SMMAP, MMAPINCR, 
 		SHARE, SSHARE, SOCKET, SOCKETGZ, VAR, HIST, POST, PHOTO};
-  enum MosaicType {NOMOSAIC, IRAF, WCSMOSAIC, WFPC2};
+  enum MosaicType {NOMOSAIC, IRAF, WCSMOSAIC};
   enum LayerType {IMG, MASK};
   enum CutMethod {SUM,AVERAGE};
 
@@ -153,11 +154,7 @@ public:
   UndoMarkerType undoMarkerType; // type
 
   Vector markerBegin;        // marker move begin in image coords
-  Marker* editMarker;        // pointer to marker currently being edited
-  Marker* rotateMarker;      // pointer to marker currently being rotated
-  Vector regionBegin;        // select region begin in canvas coords
-  Vector regionEnd;          // select region end in canvas coords
-
+  Marker* editMarker;        // pointer to current being edited/moved/rotated
   Composite* compositeMarker; // pointer to current composite marker
 
   Vector cursor; // current cursor position in REF coords
@@ -170,7 +167,6 @@ public:
 
   Context* currentContext;
   Context* keyContext;
-  int keyContextSet;
 
   Coord::Orientation orientation;   // current image orientation
   Matrix orientationMatrix;  // current image orientation matrix
@@ -182,11 +178,8 @@ public:
 
   Vector zoom_; // current image zoom value
 
-  Pixmap panPM;              // tmp pixmap for pan motion
-  Vector panCursor;          // cursor for interactive panning
-  GC panGCXOR;               // GC for interactive panning
-
-  GC rotateGCXOR;            // GC for interactive rotation
+  Vector panCursor;          // tmp cursor for interactive panning
+  Vector panStart;           // tmp pan start
 
   Pixmap pannerPixmap;       // pixmap for panner
   XImage* pannerXImage;      // ximage for panner
@@ -208,8 +201,10 @@ public:
   Vector magnifierCursor;    // we need to save the last cursor used
   char* magnifierColorName;
 
-  Vector cropBegin;
-  Vector cropEnd;
+  int doAnts;
+  int doAnts3d;
+  Vector antsBegin;
+  Vector antsEnd;
 
   Coord::CoordSystem wcsSystem_;
   Coord::SkyFrame wcsSkyFrame_;
@@ -228,18 +223,11 @@ public:
   Coord::Orientation irafOrientation_; // orientation of first iraf segment
   Matrix irafMatrix_; // orientation matrix for iraf mosaic
 
-  char* maskColorName;
-  float maskAlpha;
-  int maskMark;
-
   int invert;
 
   int useHighlite;
   GC highliteGC;
 
-  XRectangle rectWidget[1];
-  XRectangle rectWindow[1];
-
   int useCrosshair;
 
   int precLinear_;
@@ -269,13 +257,8 @@ public:
 
   GC contourGC_;
 
-  char* bgColorName;
-  XColor* bgColor;
-  char bgTrueColor_[4];   // color encoded
-
-  char* nanColorName;
-  XColor* nanColor;
-  char nanTrueColor_[4];  // color encoded
+  char* bgColourName;
+  char* nanColourName;
 
   float dlist[2];
 
@@ -383,7 +366,7 @@ public:
   virtual int isFrame3d() {return 0;}
   virtual int isFrameRGB() {return 0;}
 
-  void loadDone(int, LayerType);
+  virtual void loadDone(int);
 
   void markerAnalysisHistogram(Marker*, double**, double**, const BBox&, int);
   int markerAnalysisPlot2d(Marker*, double**, double**, double**, double**,
@@ -391,12 +374,11 @@ public:
 			   Coord::CoordSystem, Coord::SkyFrame, 
 			   Marker::AnalysisMethod);
   int markerAnalysisPlot3d(Marker*, double**, double**, const BBox&,
-			   Coord::CoordSystem, Coord::SkyFrame,
-			   Marker::AnalysisMethod);
+			   Coord::CoordSystem, Marker::AnalysisMethod);
   int markerAnalysisRadial(Marker*, double**, double**, double**, 
 			   int, Vector*, BBox*, Coord::CoordSystem);
   int markerAnalysisPanda(Marker*, double**, double**, double**, 
-			  int, Vector*, int, double*, 
+			  int, Vector*, int,
 			  BBox*, Coord::CoordSystem);
   int markerAnalysisStats1(Marker*, FitsImage*, ostream&, 
 			   Coord::CoordSystem, Coord::SkyFrame);
@@ -438,13 +420,18 @@ public:
   void psCrosshair(PSColorSpace);
   virtual void psGraphics(PSColorSpace) {}
   void psImage(ostream&, Filter&, int, int, float);
-  void psMarkers(List<Marker>*, int);
+  void psMarkers(List<Marker>*, PSColorSpace);
   Matrix psMatrix(float scale, int width, int height);
-  virtual void pushMatrices();
-  virtual void pushMagnifierMatrices();
-  virtual void pushPannerMatrices();
-  virtual void pushPSMatrices(float, int, int);
+  void pushMatrices(FitsImage*, Matrix&);
+  void pushMagnifierMatrices(FitsImage*);
+  void pushPannerMatrices(FitsImage*);
+  void pushPSMatrices(FitsImage*, float, int, int);
 
+  virtual void pushMatrices() =0;
+  virtual void pushMagnifierMatrices() =0;
+  virtual void pushPannerMatrices() =0;
+  virtual void pushPSMatrices(float, int, int) =0;
+  
   virtual void reset();
   void resetSecMode();
 
@@ -478,19 +465,20 @@ public:
 
   void updateNow(UpdateType); 
   void updateNow(UpdateType,BBox);
-  virtual void updatePanner();
+  virtual void updatePanner() =0;
   void updatePM(const BBox&);
 
   char* varcat(char*, char*, char, char*);
   virtual int validColorScale() =0;
 
+  void x11Ants();
+  virtual void x11Ants3d() {}
   void x11Crosshair(Pixmap, Coord::InternalSystem, int, int);
   void x11Dash(GC, int);
   virtual void x11Graphics();
   virtual void x11MagnifierCursor(const Vector&) {}
   void x11MagnifierMarkers(List<Marker>*, const BBox& bb);
   void x11Markers(List<Marker>*, const BBox&);
-  void x11MarkerXOR(Marker*);
   void xmlParse(istream&);
   void xmlParseFIELD(void*, int*, char**, char**, char**, char**, int);
   void xmlParseTR(char**, int*, char**, char**, char**, char**, int);
@@ -669,7 +657,6 @@ public:
   void getColorbarTagCmd();
 
   // Contour Commands
-  void contourAppendCmd(ContourLevel*);
   void contourCreateCmd(const char*, int, int, FVContour::Method, int, int, FrScale::ColorScaleType, float, FrScale::ClipMode, float, FrScale::ClipScope, double, double, const char*);
   void contourCreatePolygonCmd();
   void contourDeleteCmd();
@@ -771,46 +758,46 @@ public:
   void getFitsObjectNameCmd();
   void getFitsSizeCmd();
   void getFitsSizeCmd(Coord::CoordSystem, Coord::SkyFrame, Coord::DistFormat);
-  void getFitsSliceCmd();
-  void getFitsSliceFromImageCmd(Coord::CoordSystem, Coord::SkyFrame);
-  void getFitsSliceFromImageCmd(int, Coord::CoordSystem, Coord::SkyFrame);
-  void getFitsSliceToImageCmd(double, Coord::CoordSystem, Coord::SkyFrame);
+  void getFitsSliceCmd(int);
+  void getFitsSliceFromImageCmd(Coord::CoordSystem);
+  void getFitsSliceFromImageCmd(int, Coord::CoordSystem);
+  void getFitsSliceToImageCmd(double, Coord::CoordSystem);
   void hasFitsCmd();
   void hasFitsHPXCmd();
   void hasFitsBinCmd();
   void hasFitsCubeCmd();
   void hasFitsMosaicCmd();
 
-  void loadFitsAllocCmd(const char*, const char*, LayerType);
-  void loadFitsAllocGZCmd(const char*, const char*, LayerType);
-  void loadFitsChannelCmd(const char*, const char*, LayerType);
-  void loadFitsMMapCmd(const char*, LayerType);
-  void loadFitsSMMapCmd(const char*, const char*, LayerType);
-  void loadFitsMMapIncrCmd(const char*, LayerType);
-  void loadFitsShareCmd(ShmType, int, const char*, LayerType);
-  void loadFitsSShareCmd(ShmType, int, int, const char*, LayerType);
-  void loadFitsSocketCmd(int, const char*, LayerType);
-  void loadFitsSocketGZCmd(int, const char*, LayerType);
-  void loadFitsVarCmd(const char*, const char*, LayerType);
+  virtual void loadFitsAllocCmd(const char*, const char*, LayerType);
+  virtual void loadFitsAllocGZCmd(const char*, const char*, LayerType);
+  virtual void loadFitsChannelCmd(const char*, const char*, LayerType);
+  virtual void loadFitsMMapCmd(const char*, LayerType);
+  virtual void loadFitsSMMapCmd(const char*, const char*, LayerType);
+  virtual void loadFitsMMapIncrCmd(const char*, LayerType);
+  virtual void loadFitsShareCmd(ShmType, int, const char*, LayerType);
+  virtual void loadFitsSShareCmd(ShmType, int, int, const char*, LayerType);
+  virtual void loadFitsSocketCmd(int, const char*, LayerType);
+  virtual void loadFitsSocketGZCmd(int, const char*, LayerType);
+  virtual void loadFitsVarCmd(const char*, const char*, LayerType);
 
-  void loadArrAllocCmd(const char*, const char*, LayerType);
-  void loadArrAllocGZCmd(const char*, const char*, LayerType);
-  void loadArrChannelCmd(const char*, const char*, LayerType);
-  void loadArrMMapCmd(const char*, LayerType);
-  void loadArrMMapIncrCmd(const char*, LayerType);
-  void loadArrShareCmd(ShmType, int, const char*, LayerType);
-  void loadArrSocketCmd(int, const char*, LayerType);
-  void loadArrSocketGZCmd(int, const char*, LayerType);
-  void loadArrVarCmd(const char*, const char*, LayerType);
+  virtual void loadArrAllocCmd(const char*, const char*, LayerType);
+  virtual void loadArrAllocGZCmd(const char*, const char*, LayerType);
+  virtual void loadArrChannelCmd(const char*, const char*, LayerType);
+  virtual void loadArrMMapCmd(const char*, LayerType);
+  virtual void loadArrMMapIncrCmd(const char*, LayerType);
+  virtual void loadArrShareCmd(ShmType, int, const char*, LayerType);
+  virtual void loadArrSocketCmd(int, const char*, LayerType);
+  virtual void loadArrSocketGZCmd(int, const char*, LayerType);
+  virtual void loadArrVarCmd(const char*, const char*, LayerType);
 
   void loadENVISMMapCmd(const char*, const char*);
 
-  void loadNRRDAllocCmd(const char*, const char*, LayerType);
-  void loadNRRDChannelCmd(const char*, const char*, LayerType);
-  void loadNRRDMMapCmd(const char*, LayerType);
-  void loadNRRDShareCmd(ShmType, int, const char*, LayerType);
-  void loadNRRDSocketCmd(int, const char*, LayerType);
-  void loadNRRDVarCmd(const char*, const char*, LayerType);
+  virtual void loadNRRDAllocCmd(const char*, const char*, LayerType);
+  virtual void loadNRRDChannelCmd(const char*, const char*, LayerType);
+  virtual void loadNRRDMMapCmd(const char*, LayerType);
+  virtual void loadNRRDShareCmd(ShmType, int, const char*, LayerType);
+  virtual void loadNRRDSocketCmd(int, const char*, LayerType);
+  virtual void loadNRRDVarCmd(const char*, const char*, LayerType);
 
   virtual void loadPhotoCmd(const char*, const char*);
   virtual void loadSlicePhotoCmd(const char*, const char*);
@@ -837,37 +824,37 @@ public:
   void loadSliceSocketGZCmd(int, const char*);
   void loadSliceVarCmd(const char*, const char*);
 
-  void loadMosaicImageAllocCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
-  void loadMosaicImageAllocGZCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
-  void loadMosaicImageChannelCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
-  void loadMosaicImageMMapCmd(MosaicType, Coord::CoordSystem, const char*, LayerType);
-  void loadMosaicImageMMapIncrCmd(MosaicType, Coord::CoordSystem, const char*, LayerType);
-  void loadMosaicImageShareCmd(MosaicType, Coord::CoordSystem, ShmType, int, const char*, LayerType);
-  void loadMosaicImageSocketCmd(MosaicType, Coord::CoordSystem, int, const char*, LayerType);
-  void loadMosaicImageSocketGZCmd(MosaicType, Coord::CoordSystem, int, const char*, LayerType);
-  void loadMosaicImageVarCmd(MosaicType, Coord::CoordSystem, const char*,const char*, LayerType);
+  virtual void loadMosaicImageAllocCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
+  virtual void loadMosaicImageAllocGZCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
+  virtual void loadMosaicImageChannelCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
+  virtual void loadMosaicImageMMapCmd(MosaicType, Coord::CoordSystem, const char*, LayerType);
+  virtual void loadMosaicImageMMapIncrCmd(MosaicType, Coord::CoordSystem, const char*, LayerType);
+  virtual void loadMosaicImageShareCmd(MosaicType, Coord::CoordSystem, ShmType, int, const char*, LayerType);
+  virtual void loadMosaicImageSocketCmd(MosaicType, Coord::CoordSystem, int, const char*, LayerType);
+  virtual void loadMosaicImageSocketGZCmd(MosaicType, Coord::CoordSystem, int, const char*, LayerType);
+  virtual void loadMosaicImageVarCmd(MosaicType, Coord::CoordSystem, const char*,const char*, LayerType);
 
-  void loadMosaicAllocCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
-  void loadMosaicAllocGZCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
-  void loadMosaicChannelCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
-  void loadMosaicMMapCmd(MosaicType, Coord::CoordSystem, const char*, LayerType);
-  void loadMosaicSMMapCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
-  void loadMosaicMMapIncrCmd(MosaicType, Coord::CoordSystem, const char*, LayerType);
-  void loadMosaicShareCmd(MosaicType, Coord::CoordSystem, ShmType, int, const char*, LayerType);
-  void loadMosaicSShareCmd(MosaicType, Coord::CoordSystem, ShmType, int, int, const char*, LayerType);
-  void loadMosaicSocketCmd(MosaicType, Coord::CoordSystem, int, const char*, LayerType);
-  void loadMosaicSocketGZCmd(MosaicType, Coord::CoordSystem, int, const char*, LayerType);
-  void loadMosaicVarCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
+  virtual void loadMosaicImageWFPC2AllocCmd(const char*, const char*, LayerType);
+  virtual void loadMosaicImageWFPC2AllocGZCmd(const char*, const char*, LayerType);
+  virtual void loadMosaicImageWFPC2ChannelCmd(const char*, const char*, LayerType);
+  virtual void loadMosaicImageWFPC2MMapCmd(const char*, LayerType);
+  virtual void loadMosaicImageWFPC2MMapIncrCmd(const char*, LayerType);
+  virtual void loadMosaicImageWFPC2ShareCmd(ShmType, int, const char*, LayerType);
+  virtual void loadMosaicImageWFPC2SocketCmd(int, const char*, LayerType);
+  virtual void loadMosaicImageWFPC2SocketGZCmd(int, const char*, LayerType);
+  virtual void loadMosaicImageWFPC2VarCmd(const char*, const char*, LayerType);
 
-  void loadMosaicImageWFPC2AllocCmd(const char*, const char*);
-  void loadMosaicImageWFPC2AllocGZCmd(const char*, const char*);
-  void loadMosaicImageWFPC2ChannelCmd(const char*, const char*);
-  void loadMosaicImageWFPC2MMapCmd(const char*);
-  void loadMosaicImageWFPC2MMapIncrCmd(const char*);
-  void loadMosaicImageWFPC2ShareCmd(ShmType, int, const char*);
-  void loadMosaicImageWFPC2SocketCmd(int, const char*);
-  void loadMosaicImageWFPC2SocketGZCmd(int, const char*);
-  void loadMosaicImageWFPC2VarCmd(const char*, const char*);
+  virtual void loadMosaicAllocCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
+  virtual void loadMosaicAllocGZCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
+  virtual void loadMosaicChannelCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
+  virtual void loadMosaicMMapCmd(MosaicType, Coord::CoordSystem, const char*, LayerType);
+  virtual void loadMosaicSMMapCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
+  virtual void loadMosaicMMapIncrCmd(MosaicType, Coord::CoordSystem, const char*, LayerType);
+  virtual void loadMosaicShareCmd(MosaicType, Coord::CoordSystem, ShmType, int, const char*, LayerType);
+  virtual void loadMosaicSShareCmd(MosaicType, Coord::CoordSystem, ShmType, int, int, const char*, LayerType);
+  virtual void loadMosaicSocketCmd(MosaicType, Coord::CoordSystem, int, const char*, LayerType);
+  virtual void loadMosaicSocketGZCmd(MosaicType, Coord::CoordSystem, int, const char*, LayerType);
+  virtual void loadMosaicVarCmd(MosaicType, Coord::CoordSystem, const char*, const char*, LayerType);
 
   // Fits RGB
   virtual void loadRGBCubeAllocCmd(const char*, const char*) {}
@@ -966,8 +953,8 @@ public:
   void saveENVI(ostream&, OutFitsStream&, FitsFile::ArchType);
   void saveENVIFileCmd(const char*, const char*, FitsFile::ArchType);
 
-  void sliceCmd(int);
-  void sliceCmd(double, Coord::CoordSystem, Coord::SkyFrame);
+  void sliceCmd(int, int);
+  void sliceCmd(double, Coord::CoordSystem);
 
   void updateFitsCmd(int);
   void updateFitsCmd(int, BBox, int);
@@ -1230,9 +1217,10 @@ public:
 				  Coord::CoordSystem, Coord::SkyFrame, 
 				  Marker::AnalysisMethod);
   void getMarkerAnalysisPlot3dCmd(int, char*, char*,
-				  Coord::CoordSystem, Coord::SkyFrame,
+				  Coord::CoordSystem,
 				  Marker::AnalysisMethod);
-  void getMarkerAnalysisPandaCmd(int, Coord::CoordSystem);
+  void getMarkerAnalysisPandaCmd(int, char*, char*, char*, Coord::CoordSystem,
+				 int);
   void getMarkerAnalysisRadialCmd(int, char*, char*, char*, Coord::CoordSystem);
   void getMarkerAnalysisStatsCmd(int, Coord::CoordSystem, Coord::SkyFrame);
 
@@ -1466,11 +1454,8 @@ public:
   void markerMoveCmd(const char*, const Vector&);
   void markerMoveCmd(int id, const Vector&);
   void markerMoveBeginCmd(const Vector&);
-  void markerMoveBeginCmd(int, const Vector&);
   void markerMoveMotionCmd(const Vector&);
-  void markerMoveMotionCmd(int, const Vector&);
   void markerMoveEndCmd();
-  void markerMoveEndCmd(int);
   void markerMoveToCmd(const Vector&, Coord::CoordSystem, Coord::SkyFrame);
   void markerMoveToCmd(const char*, const Vector&, Coord::CoordSystem, Coord::SkyFrame);
   void markerMoveToCmd(int, const Vector&, Coord::CoordSystem, Coord::SkyFrame);
@@ -1550,14 +1535,20 @@ public:
   void regionSelectShiftEndCmd();
 
   // Mask Commands
-  void getMaskColorCmd();
-  void getMaskMarkCmd();
-  void getMaskTransparencyCmd();
+  virtual void getMaskCountCmd();
 
-  void maskColorCmd(const char*);
-  void maskClearCmd();
-  void maskMarkCmd(int m) {maskMark=m;}
-  void maskTransparencyCmd(float);
+  virtual void getMaskColorCmd();
+  virtual void getMaskMarkCmd();
+  virtual void getMaskRangeCmd();
+  virtual void getMaskSystemCmd();
+  virtual void getMaskTransparencyCmd();
+
+  virtual void maskClearCmd() {};
+  virtual void maskColorCmd(const char*) {};
+  virtual void maskMarkCmd(FitsMask::MaskType) {};
+  virtual void maskRangeCmd(double,double) {};
+  virtual void maskTransparencyCmd(float) {};
+  virtual void maskSystemCmd(Coord::CoordSystem) {};
 
   // NaN Commands
   void getNANColorCmd();
@@ -1575,15 +1566,15 @@ public:
   virtual void panCmd(const Vector&, Coord::CoordSystem, Coord::SkyFrame) =0;
   virtual void panToCmd(const Vector&) =0;
   virtual void panToCmd(const Vector&, Coord::CoordSystem, Coord::SkyFrame) =0;
-  void panBeginCmd(const Vector&);
-  void panMotionCmd(const Vector&);
-  virtual void panEndCmd(const Vector&) =0;
+  virtual void panBeginCmd(const Vector&) =0;
+  virtual void panMotionCmd(const Vector&) =0;
+  void panEndCmd(const Vector& vv) {panMotionCmd(vv);}
   virtual void panBBoxCmd(const Vector&) =0;
   void panPreserveCmd(int r) {preservePan = r;}
   void rotateCmd(double);
-  virtual void rotateBeginCmd() {}
-  virtual void rotateMotionCmd(double) {}
-  virtual void rotateEndCmd() {}
+  void rotateBeginCmd();
+  void rotateMotionCmd(double);
+  void rotateEndCmd();
   void rotateToCmd(double);
   void getIRAFAlignCmd();
   void irafAlignCmd(int);
