@@ -12,7 +12,7 @@
 class Grid3d : public Grid, public Grid3dBase {
  private:
   void matrixMap(void*, Matrix3d&, const char*);
-  int doit(RenderMode);
+  void doit(RenderMode);
 
  public:
   Grid3d(Widget*, Coord::CoordSystem, Coord::SkyFrame, 
@@ -23,7 +23,7 @@ class Grid3d : public Grid, public Grid3dBase {
   const char* option() {return GridBase::option();}
 
   void x11() {doit(X11);}
-  void ps(int mode) {mode_=mode; doit(PS);}
+  void ps(PSColorSpace mode) {mode_=mode; doit(PS);}
 #ifdef MAC_OSX_TK
   void macosx() {doit(MACOSX);}
 #endif
