@@ -12,7 +12,7 @@
 class Segment : public BasePolygon {
  protected:
   void renderX(Drawable, Coord::InternalSystem, RenderMode);
-  void renderPS(int);
+  void renderPS(PSColorSpace);
 #ifdef MAC_OSX_TK
   void renderMACOSX();
 #endif
